;*******************************************************************************
;Copyright (c) Texas Instruments, Inc.  2008
;
;Component Name        : Parametric EQ  (Filename : PEQ.asmx)
;Component Description : This component performs a Parametric EQ function. 
;                        The number of inputs / and outputs can be 1 or 2 
;                        It supports 5, 7, 9, 10, 11, 15 and 20 bands (Type A and C)
;                        It supports 5, 7, 9 and 10 bands (Type B)
;                        It supports maximum gain of +12 dB and minimum gain of 
;                        -12 dB in each band
;                        The Q value for each band can lie between 1 and 10 
;
;Development start date: 15/August/2011
;$Id$
;     
;Number of Instruction Memory words used = 244,282 (5-bands, mono/stereo), 637,783 (20-bands, mono/stereo) - Type A
;                                          345,383 (5-bands, mono/stereo), 709,783 (10-bands, mono/stereo) - Type B
;                                          146,187 (5-bands, mono/stereo), 263,421 (20-bands, mono/stereo) - Type C 
;Number of Instructions Executed         = 234,272 (5-bands, mono/stereo), 627,773 (20-bands, mono/stereo) - Type A
;                                          237,275 (5-bands, mono/stereo), 378,452 (10-bands, mono/stereo) - Type B
;                                          136,177 (5-bands, mono/stereo), 253,411 (20-bands, mono/stereo) - Type C  
;Data Memory Words Used                  = 51,69 (5-bands, mono/stereo), 172,235 (20-bands, mono/stereo) - Type A
;                                          62,80 (5-bands, mono/stereo), 102,135 (10-bands, mono/stereo) - Type B
;                                          26,44 (5-bands, mono/stereo), 71, 134 (20-bands, mono/stereo) - Type C
;Coefficient Words Used                  = 60 (5-bands), 165 (20-bands) - Type A
;                                          59 (5-bands), 95 (10-bands) - Type B
;                                          80 (5-bands), 260 (20-bands) - Type C   
;Inputs                                  = 1,2
;Outputs                                 = Same as Inputs                                    
;Component usage limitations             : No 
;The property values that are used       : InstanceId, InputChannels,
;                                          TargetProcessor.Name
;The target platform(s)                  : ANY
;
;Revision Date and Notes:
;AIC3254_Filter_PEQ_v1_0000_2011_08_30
;  --> Initial version
;*******************************************************************************

.port %%prop(InstanceId).Ch1_In        %%prop(InstanceId)_PEQ_IN_1_D                                     ; Data Declaration for 1st input
.data_%%prop(TargetProcessor.Name)     %%prop(InstanceId)_PEQ_IN_1_D

%%if (%%prop(Instances) == 5)
.port %%prop(InstanceId).Ch1_Out       %%prop(InstanceId)_Ch1_y_5(n)
%%endif
%%if (%%prop(Instances) == 7)
.port %%prop(InstanceId).Ch1_Out       %%prop(InstanceId)_Ch1_y_7(n)
%%endif
%%if (%%prop(Instances) == 9)
.port %%prop(InstanceId).Ch1_Out       %%prop(InstanceId)_Ch1_y_9(n)
%%endif
%%if (%%prop(Instances) == 10)
.port %%prop(InstanceId).Ch1_Out       %%prop(InstanceId)_Ch1_y_10(n)
%%endif
%%if (%%prop(Instances) == 11)
.port %%prop(InstanceId).Ch1_Out       %%prop(InstanceId)_Ch1_y_11(n)
%%endif
%%if (%%prop(Instances) == 15)
.port %%prop(InstanceId).Ch1_Out       %%prop(InstanceId)_Ch1_y_15(n)
%%endif
%%if (%%prop(Instances) == 20)
.port %%prop(InstanceId).Ch1_Out       %%prop(InstanceId)_Ch1_y_20(n)
%%endif

%%if (%%prop(InputChannels) >= 2)

.port %%prop(InstanceId).Ch2_In  %%prop(InstanceId)_PEQ_IN_2_D                                                         ; Data format 3.29
.data_%%prop(TargetProcessor.Name)  %%prop(InstanceId)_PEQ_IN_2_D

%%if (%%prop(Instances) == 5)
.port %%prop(InstanceId).Ch2_Out       %%prop(InstanceId)_Ch2_y_5(n)
%%endif
%%if (%%prop(Instances) == 7)
.port %%prop(InstanceId).Ch2_Out       %%prop(InstanceId)_Ch2_y_7(n)
%%endif
%%if (%%prop(Instances) == 9)
.port %%prop(InstanceId).Ch2_Out       %%prop(InstanceId)_Ch2_y_9(n)
%%endif
%%if (%%prop(Instances) == 10)
.port %%prop(InstanceId).Ch2_Out       %%prop(InstanceId)_Ch2_y_10(n)
%%endif
%%if (%%prop(Instances) == 11)
.port %%prop(InstanceId).Ch2_Out       %%prop(InstanceId)_Ch2_y_11(n)
%%endif
%%if (%%prop(Instances) == 15)
.port %%prop(InstanceId).Ch2_Out       %%prop(InstanceId)_Ch2_y_15(n)
%%endif
%%if (%%prop(Instances) == 20)
.port %%prop(InstanceId).Ch2_Out       %%prop(InstanceId)_Ch2_y_20(n)
%%endif

%%endif ; InputChannels == 2


%%if("%%prop(TargetType)" == "TypeA")
.include "PEQ_TypeA.asm"
%%else
    %%if("%%prop(TargetType)" == "TypeB")
.include "PEQ_TypeB.asm"
    %%else
            %%if("%%prop(TargetType)" == "TypeC")
.include "PEQ_TypeC.asm"
            %%endif
    %%endif // TargetType
%%endif // TargetType

